"use strict";
// src/generate.ts
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const getTablesProperties_1 = require("./utils/getTablesProperties");
const generateTypes_1 = require("./utils/generateTypes/generateTypes");
const generateHooks_1 = require("./utils/generateHooks/generateHooks");
async function generate({ outputPath, prettierConfigPath = '.prettierrc', relativeSupabasePath, supabaseExportName = 'supabase', typesPath, }) {
    console.log('Generating hooks with the following arguments:', {
        outputPath,
        prettierConfigPath,
        relativeSupabasePath,
        supabaseExportName,
        typesPath,
    });
    const tablesProperties = (0, getTablesProperties_1.getTablesProperties)(typesPath);
    // Iterate through table keys and generate hooks
    const hooks = [];
    const types = [];
    for (const table of tablesProperties) {
        const tableName = table.getName();
        hooks.push(...(0, generateHooks_1.generateHooks)({
            supabaseExportName,
            tableName,
        }));
        types.push(...(0, generateTypes_1.generateTypes)({ table, tableName }));
    }
    // Create the output file content with imports and hooks
    const generatedFileContent = `
import { useMutation, useQuery, useQueryClient } from 'react-query';
import ${supabaseExportName ? `{ ${supabaseExportName} }` : 'supabase'} from '${relativeSupabasePath}';

${types.join('\n')}

${hooks.join('\n\n')}
`;
    // const prettierConfig = prettierConfigPath
    //   ? await resolveConfig(prettierConfigPath)
    //   : undefined;
    // // Format the file content using Prettier
    // const formattedFileContent = prettier.format(generatedFileContent, {
    //   parser: 'typescript',
    //   // Additional Prettier options can be added here
    //   ...(prettierConfig || {}),
    // });
    // Write the output file
    fs_1.default.writeFileSync(outputPath, generatedFileContent);
}
exports.default = generate;
