"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateTypes = void 0;
const toTypeName_1 = require("./toTypeName");
function generateTypes({ tableName, table, }) {
    // Get the table type
    const tableType = table.getTypeAtLocation(table.getValueDeclarationOrThrow());
    // Find the 'Row' property within the table type
    const rowProperty = tableType.getProperty('Row');
    if (!rowProperty) {
        throw new Error(`Unable to find Row property type for ${tableName}.`);
    }
    // Get the type of the 'Row' property
    const rowType = rowProperty.getTypeAtLocation(rowProperty.getValueDeclarationOrThrow());
    const insertProperty = tableType.getProperty('Insert');
    if (!insertProperty) {
        throw new Error(`Unable to find insert property type for ${tableName}.`);
    }
    const insertType = insertProperty.getTypeAtLocation(insertProperty.getValueDeclarationOrThrow());
    const updateProperty = tableType.getProperty('Update');
    if (!updateProperty) {
        throw new Error(`Unable to find update property type for ${tableName}.`);
    }
    const updateType = updateProperty.getTypeAtLocation(updateProperty.getValueDeclarationOrThrow());
    const rowTypeString = rowType.getText();
    const insertTypeString = insertType.getText();
    const updateTypeString = updateType.getText();
    const types = [];
    types.push(`export type ${(0, toTypeName_1.toTypeName)(tableName, 'Get')} = ${rowTypeString};`, `export type ${(0, toTypeName_1.toTypeName)(tableName, 'Add')}Request = ${insertTypeString};`, `export type ${(0, toTypeName_1.toTypeName)(tableName, 'Update')}Request = { id: string; changes: ${updateTypeString} };
    `);
    return types;
}
exports.generateTypes = generateTypes;
